@@ -5,10 +5,17 @@ import logging
 from urllib import urlencode
 from urlparse import parse_qs
 
-from django.utils import simplejson
+try:
+    import json as simplejson
+except ImportError:
+    try:
+        import simplejson
+    except ImportError:
+        from django.utils import simplejson
+
 from django.utils.datastructures import MergeDict
 
-from social_auth.backends import BaseOAuth2, OAuthBackend, USERNAME
+from social_auth.backends import BaseOAuth2, OAuthBackend
 from social_auth.exceptions import AuthCanceled
 from social_auth.utils import dsa_urlopen, setting
 
@@ -24,7 +31,7 @@ class YammerBackend(OAuthBackend):
     name = 'yammer'
     EXTRA_DATA = [
         ('id', 'id'),
-        ('expires', setting('SOCIAL_AUTH_EXPIRATION', 'expires')),
+        ('expires', 'expires'),
         ('mugshot_url', 'mugshot_url')
     ]
 
@@ -39,7 +46,7 @@ class YammerBackend(OAuthBackend):
         email = response['user']['contact']['email_addresses'][0]['address']
         mugshot_url = response['user']['mugshot_url']
         return {
-            USERNAME: username,
+            'username': username,
             'email': email,
             'fullname': full_name,
             'first_name': first_name,
