@@ -1,5 +1,6 @@
 """Django ORM models for Social Auth"""
 from django.db import models
+from django.db.models.loading import get_model
 from django.db.utils import IntegrityError
 
 from social_auth.db.base import UserSocialAuthMixin, AssociationMixin, \
@@ -53,13 +54,21 @@ class UserSocialAuth(models.Model, UserSocialAuthMixin):
 
     @classmethod
     def username_max_length(cls):
-        username_field = getattr(UserSocialAuth.user_model(), 'USERNAME_FIELD', 'username')
-        field = UserSocialAuth.user_model()._meta.get_field(username_field)
-        return field.max_length
+        return cls._field_length('USERNAME_FIELD', 'username')
+
+    @classmethod
+    def email_max_length(cls):
+        return cls._field_length('EMAIL_FIELD', 'email')
+
+    @classmethod
+    def _field_length(self, setting_name, default_name):
+        model = UserSocialAuth.user_model()
+        field_name = getattr(model, setting_name, default_name)
+        return model._meta.get_field(field_name).max_length
 
     @classmethod
     def user_model(cls):
-        return UserSocialAuth._meta.get_field('user').rel.to
+        return get_model(*USER_MODEL.split('.'))
 
 
 class Nonce(models.Model, NonceMixin):
